var indexSectionsWithContent =
{
  0: "%_abcdefhijklmnopqrstuvw",
  1: "_jkmn",
  2: "lns",
  3: "jkmns",
  4: "abcdefhiklmnopqrstuvw",
  5: "jkmns",
  6: "jkn",
  7: "jkn",
  8: "jn",
  9: "cefijklmopstw",
  10: "%d"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Modules",
  10: "Pages"
};

